

.. image:: https://circleci.com/gh/conanfanli/pyolice.svg?style=svg
   :target: https://circleci.com/gh/conanfanli/pyolice
   :alt: CircleCI


.. image:: https://codecov.io/gh/conanfanli/pyolice/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/conanfanli/pyolice
   :alt: codecov


pyolice
=======

Python code police: check source code for crimes
